import { createApp } from 'vue'
import App from './App.vue'

// Impresion
// https://oss.mycure.md/v/vue-html-to-paper
import vueHtmlToPaper from 'vue-html-to-paper';

//Bootstrap
import '@/scss/styles.scss'
import * as bootstrap from 'bootstrap'

//Fontawesome
import { library } from '@fortawesome/fontawesome-svg-core'
import { FontAwesomeIcon } from '@fortawesome/vue-fontawesome'
// A partir de aquí importamos librerías según los iconos que queramos emplear 
import { faUser } from '@fortawesome/free-solid-svg-icons'

library.add(faUser)
//Añadimos el componente dfontawesome a la variable de la APP (createApp()...)


// Pinia
import { createPinia } from 'pinia'
const pinia = createPinia()

//Configuracion de impresion

const opcionesImpresion = {
    name: '_blank',
    specs: [
      'fullscreen=yes',
      'titlebar=yes',
      'scrollbars=yes'
    ],
    styles: [
      'https://maxcdn.bootstrapcdn.com/bootstrap/latest/css/bootstrap.min.css',
      'scss/styles.scss'
    ],
    timeout: 100, // tiempo por defecto hasta que aparece la 
    autoClose: true, // especifica si la ventana se cierra o no al terminar la impresión
    windowTitle: window.document.title, // titulo de la ventana de impresión
  }

// Componentes app router

//Componentes dinamicos
const NotFound = () => import('@/components/notFound.vue')
const ListaUsuarios = () => import('@/components/listaUsuarios.vue')
const RecogidasAlimento = () => import('@/components/recogidasAlimento.vue')

//Componentes estáticos
const Home = () => import('@/components/home.vue')

import { createRouter, createWebHashHistory } from 'vue-router'
const routes = [
    {path: '/', redirect: '/home'},
    {path: '/home', component: Home, name: 'home'},
    {path: '/listaUsuarios', component: ListaUsuarios, name: 'listaUsuarios'},
    {path: '/recogidasAlimento', component: RecogidasAlimento, name: 'recogidasAlimento'},
    {path: '/:pathMatch(.*)', component: NotFound, name: 'notFound'}
    ]

const router= createRouter({
    history: createWebHashHistory(), 
    routes,
})




// App
const app = createApp(App)
app.use(pinia)
app.use(router)
app.use(vueHtmlToPaper, opcionesImpresion)
app.component('font-awesome-icon', FontAwesomeIcon)

app.mount('#app')

