import axios from "axios"
const HOST = 'http://localhost:8080/api/'
//const HOST = 'https://gearsolid-a2f9e86feda7.herokuapp.com/api/'
const FORMACION_URL = HOST + 'formaciones'
const RECOGIDAALIMENTO_URL = HOST + 'recogidasAlimento'
const COMRPOMISO_URL = HOST + 'compromisos'
const FRANJA_URL = HOST + 'franjas'
const USUARIO_URL = HOST + 'usuarios'
const USUARIO_ALTA_URL = HOST + 'usuariosAlta'

export async function llamadaAPI(method, body, path) {
    //Esta función devuelve una solicitud http hacia la api
      let config = {
        method: method ?? "get",
        maxBodyLength: Infinity,
        url: path,
        headers: {

        }
      }
      
      try{
        if (body) {
          (config.data = body), (config.headers["Content-Type"] = "application/json")
        }
        return axios.request(config)
      } catch {
        console.log(`compromiso.js: Error llamada API ${path} con metodo ${method}`)
        return null
      }
      
    }

//-----------------------------------Formaciones-----------------------------------------
// entrada formación: json con campos: 
//  fechaInicio
//  usuario
//  tipoFormacion
export async function postFormacion(formacion){
    return llamadaAPI('post',formacion,FORMACION_URL)
}

/* export function getFormaciones(){
    llamadaAPI('get',null,FORMACION_URL)
}

//entrada id: identificador del elemento formación a eliminar
export function getFormacion(id){
    llamadaAPI('get',null,FORMACION_URL)
} */

// entrada formación: json con campos: 
//  fechaInicio
//  usuario
//  tipoFormacion
export async function putFormacion(id, formacion){
  let entidad = FORMACION_URL + '/' + id  
  return llamadaAPI('put',formacion,entidad)
}

export async function patchFormacion(id, formacion){
  let entidad = FORMACION_URL + '/' + id  
  return llamadaAPI('patch',formacion,entidad)
}
/* //entrada id: identificador del elemento formación a eliminar
export function deleteFormacion(id){
    let entidad = FORMACION_URL + '/' + id
    llamadaAPI('delete',null,entidad)
} */

//---------------------------------Recogida alimento--------------------------
// entrada recogidaAlimento: json con campos: 
//  fechaInicio
//  usuario
//  tipoRaciones
//  franja
export async function postRecogidaAlimento(recogidaAlimento){
  return llamadaAPI('post',recogidaAlimento,RECOGIDAALIMENTO_URL)
}

/* export function getRecogidaAlimento(){
  llamadaAPI('get',null,RECOGIDAALIMENTO_URL)
}

//entrada id: identificador del elemento recogidaAlimento a eliminar
export function getRecogidasAlimento(id){
  llamadaAPI('get',null,RECOGIDAALIMENTO_URL)
} */

// entrada recogidaAlimento: json con campos: 
//  fechaInicio
//  usuario
//  tipoRaciones
//  franja
export async function putRecogidaAlimento(id, recogidaAlimento){
  let entidad = RECOGIDAALIMENTO_URL + '/' + id
  return llamadaAPI('put',recogidaAlimento,entidad)
}

export async function patchRecogidaAlimento(id, recogidaAlimento){
  let entidad = RECOGIDAALIMENTO_URL + '/' + id
  return llamadaAPI('patch',recogidaAlimento,entidad)
}

//entrada id: identificador del elemento recogidaAlimento a eliminar
/* export function deleteRecogidaAlimento(id){
  let entidad = RECOGIDAALIMENTO_URL + '/' + id
  llamadaAPI('delete',null,entidad)
} */

//Métodos personalizados para recogidaAlimento
export function getRecogidasAlimentoPorFranjaYGrupo(grupo,inicioSemana){
  let url= `${RECOGIDAALIMENTO_URL}/recogidas-alimento-por-grupo-y-periodo/${grupo}/${inicioSemana}`
  return llamadaAPI('get', null, url )
}

//----------------------Compromisos------------------------
// entrada compromiso: json con campos: 
//Si es Formacion:
//  fechaInicio
//  usuario
//  tipoFormacion
//Si es RecogidaAlimento:
//  fechaInicio
//  usuario
//  tipoRaciones
//  franja

export async function postCompromiso(compromiso){
  if (compromiso.tipo == "formacion"){
    return postFormacion(compromiso)
  } else if (compromiso.tipo == "recogidaAlimento"){
    return postRecogidaAlimento(compromiso)
  }
}

export async function getCompromisos(){
  return await llamadaAPI('get',null,COMRPOMISO_URL)
}

export async function getCompromisosUrl(url){
  return await llamadaAPI('get',null,url)
}

export async function getCompromisosUsuario(usuario_id){
  return await llamadaAPI('get',null,COMRPOMISO_URL + "/search/compromisos-por-usuario?id-usuario=" + usuario_id)
}

export async function putCompromiso(id,compromiso){
  if (compromiso.tipo == "formacion"){
    return await putFormacion(id,compromiso)
  } else if (compromiso.tipo == "recogidaAlimento"){
    return await putRecogidaAlimento(id, compromiso)
  }
}

export async function patchCompromiso(id,compromiso){
  if (compromiso.tipo == "formacion"){
    return await patchFormacion(id,compromiso)
  } else if (compromiso.tipo == "recogidaAlimento"){
    return await patchRecogidaAlimento(id, compromiso)
  }
}

export async function deleteCompromiso(id){
  let entidad = COMRPOMISO_URL + '/' + id
  return await llamadaAPI('delete',null,entidad)
}

export async function getFranjas(){
  return llamadaAPI('get',null,FRANJA_URL)
}

// -----------------------------------Usuarios------------------------------
export async function getUsuarios(){
  return await llamadaAPI('get',null,USUARIO_URL+"?size=400")
}

// entrada formación: json con campos: 
// Envía un post de UsuarioAlta (para que el estado sea alta) 
//  nombre
//  trabajador
//  telefono
//  numeroMenores
//  ingresosUnidadFamiliar

export async function postUsuario(usuario){
  return llamadaAPI('post',usuario,USUARIO_ALTA_URL)
}

// Envío un patch con los siguientes campos para modificar un usuario existente
//  nombre
//  trabajador
//  telefono
//  numeroMenores
//  ingresosUnidadFamiliar
export async function patchUsuario(id, usuario){
  let entidad = USUARIO_ALTA_URL + '/' + id
  return llamadaAPI('patch',usuario,entidad)
}
