import {
    postCompromiso,
    getCompromisos,
    patchCompromiso,
    deleteCompromiso,
    getRecogidasAlimentoPorFranjaYGrupo,
    llamadaAPI
} from '@/stores/api-gearsolid.js'

import { mapActions } from "pinia"
import { defineStore } from 'pinia'
import { useAlmacenFranjasStore } from './franjas'

export const useAlmacenCompromisosStore = defineStore('compromisos', {
    state: () => ({
        cargado: false,
        recogidasAlimentoPorGrupo: new Map()
    }),
    getters: {
        //Funciones que acceden y calculan valores derivados del estado del almacén
    },
    actions: {
        ...mapActions(useAlmacenFranjasStore, ['getGrupos']),
        async enviarPost(compromiso) {
            const respuestaAPI = await postCompromiso(compromiso)
            let idCompromiso = ""
            if (respuestaAPI.status == 201) {
                //El id lo marca la API (actualizo el id en el compromiso a partir de la respuesta de la API)
                idCompromiso = respuestaAPI.data._links.self.href.substring(respuestaAPI.data._links.self.href.lastIndexOf("/") + 1)
            }
            return idCompromiso
        },

        //Dado un array de recogidas de alimento (JSON) descargadas directamente de la API, devuelve un array de JSON con elementos con el siguiente formato
        // Recorre los enlaces hateoas
        //   id: ,
        //   usuario: ,
        //   fechaInicio: ,
        //   franja: ,
        //   tipoRaciones: ,
        //   numeroRaciones: 
        async formatearFranjaEnRecogidaAlimento(recogidasAlimentoDescargadas) {
            
            return await Promise.all(recogidasAlimentoDescargadas.map(async recogidaAlimentoDescargada => {
                let idRecogidaAlimento = recogidaAlimentoDescargada._links.self.href.substring(recogidaAlimentoDescargada._links.self.href.lastIndexOf("/") + 1)
                let fechaInicio = new Date(recogidaAlimentoDescargada.fechaInicio).getTime()
                let franjaApi = await llamadaAPI('get', null, recogidaAlimentoDescargada._links.franja.href)
                let franja = franjaApi.data
                let usuarioApi = await llamadaAPI('get', null, recogidaAlimentoDescargada._links.usuario.href) // id sin ruta completa (por compatibilidad con otros elementos)
                let idUsuario = usuarioApi.data._links.self.href
                return {
                    id: idRecogidaAlimento,
                    usuario: idUsuario,
                    fechaInicio: fechaInicio,
                    franja: franja._links.self.href,
                    tipoRaciones: recogidaAlimentoDescargada.tipoRaciones,
                    numeroRaciones: recogidaAlimentoDescargada.numeroRaciones
                }
            }, 0))
            
        },

        //Dado un array de formaciones (directamente desde API) lo formatea a modelo de datos en frontend
        async formatearFormaciones(formacionesDescargadas){
            let formacionesArrayFormateado =  await Promise.all(formacionesDescargadas.map(async formacionDescargada => {
                let idFormacion = formacionDescargada._links.self.href.substring(formacionDescargada._links.self.href.lastIndexOf("/") + 1)
                let fechaInicio = new Date(formacionDescargada.fechaInicio).getTime()
                let usuarioApi = await llamadaAPI('get', null, formacionDescargada._links.usuario.href) // id sin ruta completa (por compatibilidad con otros elementos)
                let idUsuario = usuarioApi.data._links.self.href
                return {
                    id: idFormacion,
                    usuario: idUsuario,
                    fechaInicio: fechaInicio,
                    tipoFormacion: formacionDescargada.tipoFormacion,
                }
            }, 0))

            return new Map(formacionesArrayFormateado.map(formacionMapa => [formacionMapa.id, {
                usuario: formacionMapa.usuario,
                fechaInicio: formacionMapa.fechaInicio,
                tipoFormacion: formacionMapa.tipoFormacion,
            } ]))
        },

         //Dado un array de recogidasAlimento (directamente desde API) lo formatea a modelo de datos en frontend
        async formatearRecogidasAlimento(recogidasAlimentoDescargadas){
            let recogidasArrayFormateado =  await this.formatearFranjaEnRecogidaAlimento(recogidasAlimentoDescargadas)

            return new Map(recogidasArrayFormateado.map(recogidaMapa => [recogidaMapa.id, {
                usuario: recogidaMapa.usuario,
                fechaInicio: recogidaMapa.fechaInicio,
                franja: recogidaMapa.franja,
                tipoRaciones: recogidaMapa.tipoRaciones,
                numeroRaciones: recogidaMapa.numeroRaciones
            } ]))
        },

        /* async descargarCompromisos() {
            const respuestaAPI = await getCompromisos()

            if (respuestaAPI.status == 200) {
                console.log(`compromiso.js: compromisos descargados`)
                if (respuestaAPI.data._embedded.formaciones != null) {
                    let formacionesDescargadas = respuestaAPI.data._embedded.formaciones
                    this.formaciones = formacionesDescargadas.map(formacionDescargada => {
                        let idFormacion = formacionDescargada._links.self.href.substring(formacionDescargada._links.self.href.lastIndexOf("/") + 1)
                        let fechaInicio = new Date(formacionDescargada.fechaInicio).getTime()
                        return {
                            id: idFormacion,
                            usuario: formacionDescargada.usuario,
                            fechaInicio: fechaInicio,
                            tipoFormacion: formacionDescargada.tipoFormacion,
                        }
                    }, 0)

                }
                if (respuestaAPI.data._embedded.recogidasAlimento != null) {
                    let recogidasAlimentoDescargadas = respuestaAPI.data._embedded.recogidasAlimento
                    this.recogidasAlimento = await formatearFranjaEnRecogidaAlimento(recogidasAlimentoDescargadas)
                }
            }
        }, */


        

        async actualizarCompromiso(compromiso) {
            let retorno = false
            const respuestaAPI = await patchCompromiso(compromiso.id, compromiso)
            if (respuestaAPI.status == 200) {
                retorno = true
            }

            return retorno
        },

        async enviarDeleteCompromiso(compromiso) {

            const respuestaAPI = await deleteCompromiso(compromiso.id)

            let retorno=false

            if (respuestaAPI.status == 200) {
                retorno = true
            }
            return retorno
        },

        //mapea las recogidas de alimento en función del grupo al que pertenece su franja
        //  entrada: inicioSemana: hora UNIX a partir de la cual se filtran las recogidas
        async descargarRecogidasAlimentoPorGrupo(inicioSemana) {
            let grupos = await this.getGrupos()
            this.recogidasAlimentoPorGrupo = new Map()
            for (let grupo of grupos) {
                let respuestaAPI = await getRecogidasAlimentoPorFranjaYGrupo(grupo, inicioSemana)
                if (respuestaAPI.status == 200) {
                    if (respuestaAPI.data._embedded != null) {
                        this.recogidasAlimentoPorGrupo.set(grupo, 
                            await this.formatearFranjaEnRecogidaAlimento(respuestaAPI.data._embedded.recogidasAlimento))
                    }
                }

            }
            console.log(`compromisos.js: recogidas descargadas por grupos.`)
        }

    }

})