package es.mde.gearsolid.controladoresRest;

import java.util.List;
import org.springframework.data.rest.webmvc.PersistentEntityResource;
import org.springframework.data.rest.webmvc.PersistentEntityResourceAssembler;
import org.springframework.data.rest.webmvc.RepositoryRestController;
import org.springframework.hateoas.CollectionModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.ResponseBody;
import es.mde.gearsolid.repositorios.RecogidaAlimentoDAO;
import es.mde.gearsolid.entidades.RecogidaAlimento;

/**
 * Controlador con metodos HTTP no implementados en Spring o JPA para los elementos de la entidad
 * RecogidaAlimento
 * 
 * @author Rodrigo de Dios García
 * @version 0.1
 */
@RepositoryRestController
public class RecogidaAlimentoController {
  private RecogidaAlimentoDAO recogidaAlimentoDAO;

  public RecogidaAlimentoController(RecogidaAlimentoDAO recogidaAlimentoDAO) {
    this.recogidaAlimentoDAO = recogidaAlimentoDAO;
  }

  /**
   * Devuelve una List con las Recogidas de alimento dadas para un grupo (días de recogida) a partir
   * de una fecha de incio
   * 
   * @param grupo Grupo que debe coincidir con el campo días de la franja asociada a la Recogida de
   *        Alimento
   * @param inicioSemana Fecha a partir de la cual se muestran Recogidas de alimento activas
   * @param assembler Inyectado por Spring permite representar una entidad de JPA como un recurso
   *        REST
   * @return Retorna una coleccion de PersistentEntityResource que exponen datos de entidades como
   *         recursos REST por parte de la API.
   */
  @GetMapping("/recogidasAlimento/recogidas-alimento-por-grupo-y-periodo/{grupo}/{inicioSemana}")
  @ResponseBody
  public CollectionModel<PersistentEntityResource> getRecogidaAlimentoPorGrupo(
      @PathVariable String grupo, @PathVariable Long inicioSemana,
      PersistentEntityResourceAssembler assembler) {
    List<RecogidaAlimento> recogidasAlimento =
        recogidaAlimentoDAO.getRecogidaAlimentoPorGrupo(grupo, inicioSemana);

    return assembler.toCollectionModel(recogidasAlimento);
  }


}
