package es.mde.gearsolid.entidades;

import java.util.Date;
import org.hibernate.annotations.ManyToAny;
import jakarta.persistence.Column;
import jakarta.persistence.DiscriminatorColumn;
import jakarta.persistence.DiscriminatorValue;
import jakarta.persistence.Entity;
import jakarta.persistence.FetchType;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.GenerationType;
import jakarta.persistence.Id;
import jakarta.persistence.Inheritance;
import jakarta.persistence.InheritanceType;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.Table;

/**
 * La entidad compromisos reune las propiedades comunes a todos los tipos de compromiso Campos:
 * <ul>
 * <li><b>id</b>: Valor entero</li>
 * <li><b>fechaInicio</b> fecha a partir de la cual comienza el compromiso</li>
 * <li><b>tipo</b>: formación o recogidaAlimento</li>
 * <li><b>usuario</b>: entero que recoge el id de un usuario</li>
 * </ul>
 * 
 * @author Rodrigo De Dios García
 * @version 0.1
 */

@Entity
@Table(name = "compromiso")
@Inheritance(strategy = InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name = "tipo")
@DiscriminatorValue("Compromiso")
public class Compromiso {
  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  @Column(unique = true)
  private int id;
  private Date fechaInicio;
  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name="USUARIO")
  private UsuarioAlta usuario; // id de usuario


  public Compromiso() {

  }

  public int getId() {
    return id;
  }

  public void setId(int id) {
    this.id = id;
  }


  public UsuarioAlta getUsuario() {
    return usuario;
  }

  public void setUsuario(UsuarioAlta usuario) {
    this.usuario = usuario;
  }

  public Date getFechaInicio() {
    return fechaInicio;
  }

  public void setFechaInicio(long fechaInicio) {
    this.fechaInicio = new Date(fechaInicio);
  }

}
