package es.mde.gearsolid.entidades;

import java.time.LocalTime;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonGetter;

import jakarta.persistence.CascadeType;
import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.GenerationType;
import jakarta.persistence.Id;
import jakarta.persistence.OneToMany;
import jakarta.persistence.Table;

/**
 * Representa un periodo de tiempo que se repite de forma periódica a lo largo de la semana Se
 * emplea para definir en qué momento un usuario puede efectuar la recogida de alimento
 * 
 * Al representar una capacidad de personas implementa la interfaz Aforo.
 * 
 * Campos:
 * <ul>
 * <li>id</li>
 * <li>dias: String que representa los días de la semana en que el usuario recoge alimentos Este
 * campo define un grupo (ya que los usuarios se organizan en grupos en base a los días en los que
 * recogen alimento) (Formato: A: L M J, B: M X V...)</li>
 * <li>hora: LocalTime Hora a la que comienza la franja</li>
 * <li>plazas: número máximo de personas a las que se puede asignar una flanja</li>
 * </ul>
 * 
 * @author Rodrigo de Dios García
 * @version 0.1
 * 
 * @see es.mde.gearsolid.entidades.Aforo
 */
@Entity
@Table(name = "franja")
public class Franja implements Aforo {
  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  @Column(unique = true)
  private int id;
  private String dias;
  private LocalTime hora;
  private int plazasTotales;

  @OneToMany(cascade = CascadeType.ALL, targetEntity = RecogidaAlimento.class, mappedBy = "franja")
  private List<RecogidaAlimento> recogidasAlimento;

  public Franja() {
    // TODO Auto-generated constructor stub
  }

  @Override
  public int getPlazasDisponibles() {
    // TODO Auto-generated method stub
    return this.plazasTotales - this.getRecogidasAlimento().size();
  }
  
  public boolean esDisponible() {
	  return getPlazasDisponibles() > 0;
  }

  public int getId() {
    return id;
  }

  public void setId(int id) {
    this.id = id;
  }

  public String getDias() {
    return dias;
  }

  public void setDias(String dias) {
    this.dias = dias;
  }

  public LocalTime getHora() {
    return hora;
  }

  public void setHora(LocalTime hora) {
    this.hora = hora;
  }

  public int getPlazas() {
    return plazasTotales;
  }

  public void setPlazas(int plazas) {
    this.plazasTotales = plazas;
  }

  public List<RecogidaAlimento> getRecogidasAlimento() {
    return recogidasAlimento;
  }

  public void setRecogidasAlimento(List<RecogidaAlimento> recogidasAlimento) {
    this.recogidasAlimento = recogidasAlimento;
  }

}
