/**
 * 
 */
package es.mde.gearsolid.entidades;

import org.slf4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;

import jakarta.persistence.DiscriminatorValue;
import jakarta.persistence.Entity;
import jakarta.persistence.FetchType;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.Transient;

/**
 * Entidad que recoge los elementos propios de un compromiso tipo recogida de alimento Campos:
 * <ul>
 * <li><b>numeroRaciones:</b> Número de raciones que el usuario debe recoger</li>
 * <li><b>tipoRaciones:</b> String (halal, alergia, mediterraneo...)</li>
 * <li><b>franja:</b>Objeto Franja (Entity de Spring) que representa la franja temporal asignada a
 * la Recogida</li>
 * </ul>
 * 
 * @author Rodrigo de Dios García
 * @version 0.1
 */
@Entity
@DiscriminatorValue("RecogidaAlimento")
public class RecogidaAlimento extends Compromiso {

  private int numeroRaciones;
  private String tipoRaciones;
  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "FRANJA")
  private Franja franja;
  
  @Transient
  private Logger log;
  

  public RecogidaAlimento() {

  }

  public int getNumeroRaciones() {
    return numeroRaciones;
  }

  public void setNumeroRaciones(int numeroRaciones) {
    this.numeroRaciones = numeroRaciones;
  }

  public String getTipoRaciones() {
    return tipoRaciones;
  }

  public void setTipoRaciones(String tipoRaciones) {
    this.tipoRaciones = tipoRaciones;
  }

  public Franja getFranja() {
    return franja;
  }

  public void setFranja(Franja franja) {
    if (franja.esDisponible()) {
    	this.franja = franja;
    } else {
    	log.warn("Se ha intentado añadir una franja completa en el objeto recogida de alimeto.");
    }
	  
  }
  @Autowired
  public void setLog(Logger log) {
	  this.log = log;
  }

}
