package es.mde.gearsolid.entidades;

import jakarta.persistence.Column;
import jakarta.persistence.DiscriminatorColumn;
import jakarta.persistence.DiscriminatorValue;
import jakarta.persistence.Entity;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.GenerationType;
import jakarta.persistence.Id;
import jakarta.persistence.Inheritance;
import jakarta.persistence.InheritanceType;
import jakarta.persistence.Table;

/**
 * Entidad que recoge los datos de los usuarios. Campos:
 * <ul>
 * <li><b>id:</b> int Identificador autogenerado</li>
 * <li><b>nombre:</b> String Nombre del usuario</li>
 * <li><b>estado:</b> String (alta/baja/pendiente)</li>
 * <li><b>trabajador:</b> String Nombre del trabajador vinculado al usuario</li>
 * </ul>
 * 
 * @author Rodrigo de Dios García
 * @version 0.1
 */
@Entity
@Table(name = "usuario")
@Inheritance(strategy=InheritanceType.SINGLE_TABLE) 
@DiscriminatorColumn(name = "estado")
@DiscriminatorValue("pendiente")
public class Usuario {
	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	@Column(unique = true)
	private int id;
	@Column
	private String nombre;
	@Column
	private String trabajador;
	public int getId() {
		return id;
	}
	public void setId(int id) {
		this.id = id;
	}
	public String getNombre() {
		return nombre;
	}
	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	public String getTrabajador() {
		return trabajador;
	}
	public void setTrabajador(String trabajador) {
		this.trabajador = trabajador;
	}
}
