package es.mde.gearsolid.entidades;

import java.util.List;

import jakarta.persistence.CascadeType;
import jakarta.persistence.Column;
import jakarta.persistence.DiscriminatorValue;
import jakarta.persistence.Entity;
import jakarta.persistence.OneToMany;

/**
 * Entidad que recoge los datos de los usuarios que están dados de alta. Campos:
 * <ul>
 * <li><b>id:</b> int Identificador autogenerado</li>
 * <li><b>teléfono:</b> String (número de teléfono del usuario, se emplea String
 * para permitir inclusión de prefijos o varios números)</li>
 * <li><b>numeroMenores:</b> int número a de menores a cargo del usuario</li>
 * <li><b>igresosUnidadFamiliar:</b> float ingresos de la Unidad familiar a la que pertenece el usuario</li>
 * </ul>
 * 
 * @author Rodrigo de Dios García
 * @version 0.1
 */
@Entity
@DiscriminatorValue("alta")
public class UsuarioAlta extends Usuario{
	@Column
	private String telefono;
	@Column
	private int numeroMenores;
	@Column
	private float ingresosUnidadFamiliar;
	@Column
	@OneToMany(cascade = CascadeType.ALL, targetEntity = Compromiso.class, mappedBy = "usuario")
	List<Compromiso> compromisos;

	public String getTelefono() {
		return telefono;
	}

	public void setTelefono(String telefono) {
		this.telefono = telefono;
	}

	public int getNumeroMenores() {
		return numeroMenores;
	}

	public void setNumeroMenores(int numeroMenores) {
		this.numeroMenores = numeroMenores;
	}

	public float getIngresosUnidadFamiliar() {
		return ingresosUnidadFamiliar;
	}

	public void setIngresosUnidadFamiliar(float ingresosUnidadFamiliar) {
		this.ingresosUnidadFamiliar = ingresosUnidadFamiliar;
	}
}
